@@ -8,6 +8,7 @@ import yaml
 from steam_sdk.data.DataSettings import DataSettingsSTEAM
 from steam_sdk.builders.BuilderModel import BuilderModel
 from steam_sdk.data.DataAnalysis import DataAnalysis, ModifyModel
+from steam_sdk.drivers.DriverFiQuS import DriverFiQuS
 from steam_sdk.drivers.DriverLEDET import DriverLEDET
 from steam_sdk.drivers.DriverPSPICE import DriverPSPICE
 from steam_sdk.drivers.DriverPyBBQ import DriverPyBBQ
@@ -239,6 +240,8 @@ class AnalysisSTEAM:
 
         # Build simulation file
         if step.simulation_number:
+            if 'FiQuS' in step.software:
+                self.setup_sim_FiQuS(simulation_name=step.simulation_name, sim_number=step.simulation_number)
             if 'LEDET' in step.software:
                 flag_yaml = True  # Hard-coded for the moment
                 self.setup_sim_LEDET(simulation_name=step.simulation_name, sim_number=step.simulation_number, flag_yaml=flag_yaml, flag_json=flag_json)
@@ -308,6 +311,9 @@ class AnalysisSTEAM:
             # Build simulation file
             if len_simulation_numbers > 0:
                 simulation_number = step.simulation_numbers[v]
+                if 'FiQuS' in step.software:
+                    BM.buildFiQuS()
+                    self.setup_sim_FiQuS(simulation_name=step.simulation_name, sim_number=simulation_number)
                 if 'LEDET' in step.software:
                     flag_json = BM.flag_json
                     flag_yaml = True  # Hard-coded for the moment
@@ -497,7 +503,7 @@ class AnalysisSTEAM:
         # Unpack
         full_path_aux_file = Path(step.full_path_aux_file).resolve()
         new_file_name      = step.new_file_name
-        output_path = self.output_path
+        output_path        = self.output_path
 
         # If no new name is provided, use the old file name
         if new_file_name == None:
@@ -512,6 +518,8 @@ class AnalysisSTEAM:
         len_simulation_numbers = len(step.simulation_numbers)
         if len_simulation_numbers > 0:
             for simulation_number in step.simulation_numbers:
+                if 'FiQuS' in step.software:
+                    self.setup_sim_FiQuS(simulation_name=step.simulation_name, sim_number=simulation_number)
                 if 'LEDET' in step.software:
                     flag_yaml = True  # Hard-coded for the moment
                     flag_json = False  # Hard-coded for the moment
@@ -521,6 +529,41 @@ class AnalysisSTEAM:
                 if 'PSPICE' in step.software:
                     self.setup_sim_PSPICE(simulation_name=step.simulation_name, sim_number=simulation_number)
 
+
+    def setup_sim_FiQuS(self, simulation_name, sim_number):
+        """
+        Set up a FiQuS simulation by copying the last file generated by BuilderModel to the output folder and to the
+        local FiQuS working folder.
+        The original file is then deleted.
+        """
+
+        # Unpack
+        output_folder = self.output_path
+        local_FiQuS_folder = Path(self.settings.local_FiQuS_folder)
+
+        # Add simulation number to the list
+        self.list_sims.append(sim_number)
+
+        # Make simulation folder
+        local_model_folder = os.path.join(local_FiQuS_folder, simulation_name, str(sim_number))
+        make_folder_if_not_existing(local_model_folder)
+
+        # Copy simulation file
+        file_name_temp = os.path.join(output_folder, simulation_name)
+        yaml_temp = os.path.join(file_name_temp + '.yaml')
+        geo_temp = os.path.join(file_name_temp + '.geom')
+        set_temp = os.path.join(file_name_temp + '.set')
+        file_name_local = os.path.join(local_model_folder, simulation_name)
+        yaml_local = os.path.join(file_name_local + '.yaml')
+        geo_local = os.path.join(file_name_local + '.geom')
+        set_local = os.path.join(file_name_local + '.set')
+        print('Simulation files {} generated.'.format(file_name_temp))
+
+        shutil.copyfile(yaml_temp, yaml_local)
+        shutil.copyfile(geo_temp, geo_local)
+        shutil.copyfile(set_temp, set_local)
+        print('Simulation files {} copied.'.format(file_name_local))
+
     def setup_sim_LEDET(self, simulation_name, sim_number, flag_yaml=True, flag_json=False):
         '''
         Set up a LEDET simulation by copying the last file generated by BuilderModel to the output folder and to the
@@ -640,11 +683,17 @@ class AnalysisSTEAM:
         Run selected simulation.
         The function applies a different logic for each simulation software.
         '''
-        if software == 'LEDET':
+        if software == 'FiQuS':
+            local_model_folder_input = os.path.join(self.settings.local_FiQuS_folder, simulation_name, str(sim_number))
+            relative_folder_output = os.path.join(simulation_name, str(sim_number))
+            dFiQuS = DriverFiQuS(path_exe=self.settings.FiQuS_path, path_folder_FiQuS=self.settings.local_FiQuS_folder,
+                                 path_folder_FiQuS_input=local_model_folder_input, verbose=verbose)
+            dFiQuS.run_FiQuS(simulation_name, outputDirectory=relative_folder_output)
+        elif software == 'LEDET':
             dLEDET = DriverLEDET(path_exe=self.settings.LEDET_path, path_folder_LEDET=self.settings.local_LEDET_folder, verbose=verbose)
             dLEDET.run_LEDET(simulation_name, str(sim_number), simFileType=simFileType)
         elif software == 'PyBBQ':
-            local_model_folder_input  = os.path.join(self.settings.local_PyBBQ_folder, simulation_name, str(sim_number))
+            local_model_folder_input = os.path.join(self.settings.local_PyBBQ_folder, simulation_name, str(sim_number))
             relative_folder_output = os.path.join(simulation_name, str(sim_number))
             dPyBBQ = DriverPyBBQ(path_exe=self.settings.PyBBQ_path, path_folder_PyBBQ=self.settings.local_PyBBQ_folder, path_folder_PyBBQ_input=local_model_folder_input, verbose=verbose)
             dPyBBQ.run_PyBBQ(simulation_name, outputDirectory=relative_folder_output)
