@@ -274,7 +274,7 @@ class BuilderModel:
             Building a FiQuS model
         """
         builder_FiQuS = BuilderFiQuS(input_model_data=self.model_data, input_roxie_data=self.roxie_data,
-                                     flag_build=self.flag_build, verbose=self.verbose)
+                                     flag_build=self.flag_build, flag_plot_all=self.flag_plot_all, verbose=self.verbose)
 
         # Write output files
         parser_FiQuS = ParserFiQuS(builder_FiQuS)
