@@ -48,7 +48,6 @@ class GeometryBBQ(BaseModel):
         Level 2: Class for geometry options in BBQ
     """
     thInsul: float = None
-    lenBusbar: float = None
 
 
 class SimulationBBQ(BaseModel):
@@ -109,7 +108,6 @@ class GeometryPyBBQ(BaseModel):
         Level 2: Class for geometry options in PyBBQ
     """
     thInsul: float = None
-    lenBusbar: float = None
     tapetype: str = None
 
 
@@ -179,7 +177,7 @@ class PyBBQ(BaseModel):
     """
         Level 1: Class for PyBBQ options
     """
-    geometry: GeometryBBQ = GeometryBBQ()
+    geometry: GeometryPyBBQ = GeometryPyBBQ()
     magnetic_field: MagneticFieldPyBBQ = MagneticFieldPyBBQ()
     simulation: SimulationPyBBQ = SimulationPyBBQ()
     physics: PhysicsPyBBQ = PhysicsPyBBQ()
