@@ -4,6 +4,7 @@ from typing import (Deque, Dict, FrozenSet, List, Optional, Sequence, Set, Tuple
 import ruamel.yaml
 
 from steam_sdk.data.DataConductor import Conductor
+from steam_sdk.data.DataFiQuS import OptionFiQuS
 
 
 ############################
@@ -52,6 +53,7 @@ class ElectricalOrder(BaseModel):
     """
     group_together: List[List[int]] = []   # elPairs_GroupTogether
     reversed: List[int] = []         # elPairs_RevElOrder
+    overwrite_electrical_order: List[int] = []
 
 
 class Multipole(BaseModel):
@@ -250,12 +252,12 @@ class QuenchInitializationBBQ(BaseModel):
 
 
 ############################
-# FiQuS options
-class FiQuS(BaseModel):
-    """
-        Level 1: Class for FiQuS options
-    """
-    tbc: int = None
+# # FiQuS options
+# class FiQuS(BaseModel):
+#     """
+#         Level 1: Class for FiQuS options
+#     """
+#     tbc: int = None
 
 
 ############################
@@ -273,6 +275,7 @@ class MagnetInductance(BaseModel):
     """
     flag_calculate_inductance: bool = None
     overwrite_inductance_coil_sections: List[List[float]] = [[]]
+    overwrite_HalfTurnToInductanceBlock: List[int] = []
     LUT_DifferentialInductance_current: List[float] = []
     LUT_DifferentialInductance_inductance: List[float] = []
 
@@ -485,7 +488,7 @@ class LEDET(BaseModel):
 ############################
 # ProteCCT options
 class TimeVectorProteCCT(BaseModel):
-    """"
+    """
         Level 2: Class for ProteCCT time vector options
     """
     tMaxStopCondition: float = None
@@ -493,7 +496,7 @@ class TimeVectorProteCCT(BaseModel):
 
 
 class GeometryGenerationOptionsProteCCT(BaseModel):
-    """"
+    """
         Level 2: Class for ProteCCT geometry generation options
     """
     totalConductorLength: float = None
@@ -508,7 +511,7 @@ class GeometryGenerationOptionsProteCCT(BaseModel):
 
 
 class PhysicsProteCCT(BaseModel):
-    """"
+    """
         Level 2: Class for ProteCCT physics options
     """
     M: List[List[float]] = [[]]
@@ -525,7 +528,7 @@ class PhysicsProteCCT(BaseModel):
 
 
 class SimulationProteCCT(BaseModel):
-    """"
+    """
         Level 2: Class for ProteCCT physics options
     """
     tempMaxStopCondition: float = None
@@ -541,7 +544,7 @@ class SimulationProteCCT(BaseModel):
 
 
 class PlotsProteCCT(BaseModel):
-    """"
+    """
         Level 2: Class for ProteCCT plots options
     """
     withPlots: int = None
@@ -549,7 +552,7 @@ class PlotsProteCCT(BaseModel):
 
 
 class PostProcessingProteCCT(BaseModel):
-    """"
+    """
         Level 2: Class for ProteCCT post-processing options
     """
     withVoltageEvaluation: int = None
@@ -557,7 +560,7 @@ class PostProcessingProteCCT(BaseModel):
 
 
 class PROTECCT(BaseModel):
-    """"
+    """
         Level 1: Class for ProteCCT options
     """
     time_vector: TimeVectorProteCCT = TimeVectorProteCCT()
@@ -618,7 +621,7 @@ class SIGMA(BaseModel):
 ############################
 # Highest level
 class DataModelMagnet(BaseModel):
-    '''
+    """
         **Class for the STEAM inputs**
 
         This class contains the data structure of STEAM model inputs.
@@ -629,7 +632,7 @@ class DataModelMagnet(BaseModel):
         :type n: int
 
         :return: DataModelMagnet object
-    '''
+    """
 
     Sources: SourceFiles = SourceFiles()
     GeneralParameters: General = General()
@@ -638,7 +641,7 @@ class DataModelMagnet(BaseModel):
     Circuit: Circuit = Circuit()
     Power_Supply: PowerSupply = PowerSupply()
     Quench_Protection: QuenchProtection = QuenchProtection()
-    Options_FiQuS: FiQuS = FiQuS()
+    Options_FiQuS: OptionFiQuS = OptionFiQuS()
     Options_LEDET: LEDET = LEDET()
     Options_ProteCCT: PROTECCT = PROTECCT()
     Options_SIGMA: SIGMA = SIGMA()
