@@ -175,7 +175,7 @@ def get_template_LEDET_options_sheet():
         ['fieldMapNumber', None, 'Number defining a set of magnetic-field maps, whose names should end with a suffix "_N", where N is  the set number'],
         [None, None, None],
         [None, None, 'Input Generation Options'],
-        ['flag_typeWindings', None, 'Coil windings type. 0=Multipole coil 1=Solenoid, 101=Busbar. Default: 0'],
+        ['flag_typeWindings', None, 'Coil windings type. 0=Multipole coil. 1=Solenoid. 2=CCT coil. 101=Busbar. Default: 0'],
         ['flag_calculateInductanceMatrix', None, 'If set to >0, enables the automatic calculation of the self- and mutual inductances between each turn, and between each coil section. If set to 2, it also write an output txt file with the calculated values; this file is saved in the subfolder "Output\Txt Files".'],
         ['flag_useExternalInitialization', None, 'If set to 1, LEDET will look for an initialization file in a specified folder to load all input properties and magnetic field parameters; if the file is not there, it will generate it (default=0)'],
         ['flag_initializeVar', None, 'Initialize selected variables from a txt files. The variables are defined in the "Variables" sheet'],
@@ -263,7 +263,7 @@ def get_template_LEDET_variables_sheet():
         ['variableToInitialize', None, 'Variables to load from exchange files'],
         [None, None, None],
         [None, None, 'Variables for assigning variables to mesh elements (each column is a different output)'],
-        ['writeToMesh_fileNameMeshPositions', None, 'Name of the file defining the mesh element centers'],
+        ['writeToMesh_fileNameMeshPositions', None, 'Name of the file defining the mesh element centers. The file must include a header with these three variables: "id_element", "x [m]", and "y [m]".'],
         ['writeToMesh_suffixFileNameOutput', None, 'Name of the suffix of the output files. Full names will be magnet_name + suffix + simulation_number + time_step + ".RES"'],
         ['writeToMesh_selectedVariables', None, 'Selected variables that will be written to the mesh elements. More than one can be defined in each column (comma separated).'],
         ['writeToMesh_selectedTimeSteps', None, 'Selected time steps at which the results will be written to the mesh elements'],
