@@ -30,7 +30,7 @@ class ParserFiQuS:
             dictionary_yaml = ruamel.yaml.safe_load(stream)
             self.builder_FiQuS.data_FiQuS = dF.FiQuSData(**dictionary_yaml)
 
-        with open(file_name + '.geo', "r") as stream:
+        with open(file_name + '.geom', "r") as stream:
             dictionary_yaml = ruamel.yaml.safe_load(stream)
             self.builder_FiQuS.data_FiQuS = dF.FiQuSGeometry(**dictionary_yaml)
 
@@ -43,7 +43,7 @@ class ParserFiQuS:
 
     def writeFiQuS2yaml(self, full_path_file_name: str, verbose: bool = False):
         """
-        ** Writes a FiQuS yaml input file **
+        ** Writes FiQuS input files **
 
         :param full_path_file_name:
         :param verbose:
@@ -59,5 +59,5 @@ class ParserFiQuS:
             Path(output_path).mkdir(parents=True)
 
         dict_to_yaml(self.builder_FiQuS.data_FiQuS.dict(), full_path_file_name + '.yaml', list_exceptions=[])
-        dict_to_yaml(self.builder_FiQuS.data_FiQuS_geo.dict(), full_path_file_name + '.geo', list_exceptions=[])
+        dict_to_yaml(self.builder_FiQuS.data_FiQuS_geo.dict(), full_path_file_name + '.geom', list_exceptions=[])
         dict_to_yaml(self.builder_FiQuS.data_FiQuS_set.dict(), full_path_file_name + '.set', list_exceptions=[])
