@@ -641,18 +641,18 @@ def add_library(text: str):
 
 def add_global_parameter(name: str, value: str):
     ''' Format global parameters row '''
-    formatted_text = '+ ' + name + '={' + value + '}'
+    formatted_text = '+ ' + name + '={' + str(value) + '}'
     return formatted_text
 
 def add_initial_condition(name: str, value: str):
     ''' Format initial condition row '''
-    formatted_text = '.IC ' + name + ' {' + value + '}'
+    formatted_text = '.IC ' + name + ' {' + str(value) + '}'
     return formatted_text
 
 def add_standard_component(name: str, nodes: list, value: str):
     ''' Format standard component netlist row '''
     str_nodes = " ".join(nodes)  # string with space-separated nodes
-    formatted_text = name + ' (' + str_nodes + ') ' + '{' + value + '}'
+    formatted_text = name + ' (' + str_nodes + ') ' + '{' + str(value) + '}'
     return formatted_text
 
 def add_stimulus_controlled_component(name: str, nodes: list, value: str):
@@ -665,7 +665,7 @@ def add_stimulus_controlled_component(name: str, nodes: list, value: str):
 def add_pulsed_source_component(name: str, nodes: list, value: str):
     ''' Format pulsed-source component netlist row '''
     str_nodes = " ".join(nodes)  # string with space-separated nodes
-    str_pulse = 'PULSE(' + value + ')'
+    str_pulse = 'PULSE(' + str(value) + ')'
     formatted_text = name + ' (' + str_nodes + ') ' + str_pulse
     return formatted_text
 
